@@ -51,4 +51,14 @@ USER_OBJECT_ RS_XML_xmlXIncludeProcessFlags(USER_OBJECT_ r_doc, USER_OBJECT_ r_f
 
 USER_OBJECT_ processNamespaceDefinitions(xmlNs *ns, xmlNodePtr node, R_XMLSettings *parserSettings);
 
+
+
+typedef struct _R_NodeGCInfo {
+
+    struct _R_NodeGCInfo  *prev;
+    struct _R_NodeGCInfo  *next;
+    xmlNodePtr node;
+    int count;
+
+} R_NodeGCInfo;
 #endif
